==> openshift-model-hive-6.9.0-sources.jar: io/fabric8/openshift/api/model/hive/v1/FeatureGateSelectionFluent.java <==
package io.fabric8.openshift.api.model.hive.v1;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.util.LinkedHashMap;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.util.Map;

/**
 * Generated
 */
@SuppressWarnings("unchecked")
public class FeatureGateSelectionFluent<A extends FeatureGateSelectionFluent<A>> extends BaseFluent<A>{
  public FeatureGateSelectionFluent() {
  }
  
  public FeatureGateSelectionFluent(FeatureGateSelection instance) {
    this.copyInstance(instance);
  }
  private FeatureGatesEnabledBuilder custom;
  private String featureSet;
  private Map<String,Object> additionalProperties;
  
  protected void copyInstance(FeatureGateSelection instance) {
    instance = (instance != null ? instance : new FeatureGateSelection());
  
    if (instance != null) {
        this.withCustom(instance.getCustom());
        this.withFeatureSet(instance.getFeatureSet());
        this.withCustom(instance.getCustom());
        this.withFeatureSet(instance.getFeatureSet());
        this.withAdditionalProperties(instance.getAdditionalProperties());
      }
  }
  
  public FeatureGatesEnabled buildCustom() {
    return this.custom!=null ?this.custom.build():null;
  }
  
  public A withCustom(FeatureGatesEnabled custom) {
    _visitables.get("custom").remove(this.custom);
    if (custom!=null){ this.custom= new FeatureGatesEnabledBuilder(custom); _visitables.get("custom").add(this.custom);} else { this.custom = null; _visitables.get("custom").remove(this.custom); } return (A) this;
  }
  
  public boolean hasCustom() {
    return this.custom != null;
  }
  
  public CustomNested<A> withNewCustom() {
    return new CustomNested(null);
  }
  
  public CustomNested<A> withNewCustomLike(FeatureGatesEnabled item) {
    return new CustomNested(item);
  }
  
  public CustomNested<A> editCustom() {
    return withNewCustomLike(java.util.Optional.ofNullable(buildCustom()).orElse(null));
  }
  
  public CustomNested<A> editOrNewCustom() {
    return withNewCustomLike(java.util.Optional.ofNullable(buildCustom()).orElse(new FeatureGatesEnabledBuilder().build()));
  }
  
  public CustomNested<A> editOrNewCustomLike(FeatureGatesEnabled item) {
    return withNewCustomLike(java.util.Optional.ofNullable(buildCustom()).orElse(item));
  }
  
  public String getFeatureSet() {
    return this.featureSet;
  }
  
  public A withFeatureSet(String featureSet) {
    this.featureSet=featureSet; return (A) this;
  }
  
  public boolean hasFeatureSet() {
    return this.featureSet != null;
  }
  
  public A addToAdditionalProperties(String key,Object value) {
    if(this.additionalProperties == null && key != null && value != null) { this.additionalProperties = new LinkedHashMap(); }
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (A)this;
  }
  
  public A addToAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null && map != null) { this.additionalProperties = new LinkedHashMap(); }
    if(map != null) { this.additionalProperties.putAll(map);} return (A)this;
  }
  
  public A removeFromAdditionalProperties(String key) {
    if(this.additionalProperties == null) { return (A) this; }
    if(key != null && this.additionalProperties != null) {this.additionalProperties.remove(key);} return (A)this;
  }
  
  public A removeFromAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.additionalProperties != null){this.additionalProperties.remove(key);}}} return (A)this;
  }
  
  public Map<String,Object> getAdditionalProperties() {
    return this.additionalProperties;
  }
  
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties) {
    if (additionalProperties == null) { this.additionalProperties =  null;} else {this.additionalProperties = new LinkedHashMap(additionalProperties);} return (A) this;
  }
  
  public boolean hasAdditionalProperties() {
    return this.additionalProperties != null;
  }
  
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    FeatureGateSelectionFluent that = (FeatureGateSelectionFluent) o;
    if (!java.util.Objects.equals(custom, that.custom)) return false;
  
    if (!java.util.Objects.equals(featureSet, that.featureSet)) return false;
  
    if (!java.util.Objects.equals(additionalProperties, that.additionalProperties)) return false;
  
    return true;
  }
  
  public int hashCode() {
    return java.util.Objects.hash(custom,  featureSet,  additionalProperties,  super.hashCode());
  }
  
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (custom != null) { sb.append("custom:"); sb.append(custom + ","); }
    if (featureSet != null) { sb.append("featureSet:"); sb.append(featureSet + ","); }
    if (additionalProperties != null && !additionalProperties.isEmpty()) { sb.append("additionalProperties:"); sb.append(additionalProperties); }
    sb.append("}");
    return sb.toString();
  }
  public class CustomNested<N> extends FeatureGatesEnabledFluent<CustomNested<N>> implements Nested<N>{
    CustomNested(FeatureGatesEnabled item) {
      this.builder = new FeatureGatesEnabledBuilder(this, item);
    }
    FeatureGatesEnabledBuilder builder;
    
    public N and() {
      return (N) FeatureGateSelectionFluent.this.withCustom(builder.build());
    }
    
    public N endCustom() {
      return and();
    }
    
  
  }

}

==> openshift-model-hive-6.9.1-sources.jar: io/fabric8/openshift/api/model/hive/v1/FeatureGateSelectionFluent.java <==
package io.fabric8.openshift.api.model.hive.v1;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.util.LinkedHashMap;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.util.Map;

/**
 * Generated
 */
@SuppressWarnings("unchecked")
public class FeatureGateSelectionFluent<A extends FeatureGateSelectionFluent<A>> extends BaseFluent<A>{
  public FeatureGateSelectionFluent() {
  }
  
  public FeatureGateSelectionFluent(FeatureGateSelection instance) {
    this.copyInstance(instance);
  }
  private FeatureGatesEnabledBuilder custom;
  private String featureSet;
  private Map<String,Object> additionalProperties;
  
  protected void copyInstance(FeatureGateSelection instance) {
    instance = (instance != null ? instance : new FeatureGateSelection());
    if (instance != null) {
          this.withCustom(instance.getCustom());
          this.withFeatureSet(instance.getFeatureSet());
          this.withCustom(instance.getCustom());
          this.withFeatureSet(instance.getFeatureSet());
          this.withAdditionalProperties(instance.getAdditionalProperties());
        }
  }
  
  public FeatureGatesEnabled buildCustom() {
    return this.custom != null ? this.custom.build() : null;
  }
  
  public A withCustom(FeatureGatesEnabled custom) {
    this._visitables.remove(this.custom);
    if (custom != null) {
        this.custom = new FeatureGatesEnabledBuilder(custom);
        this._visitables.get("custom").add(this.custom);
    } else {
        this.custom = null;
        this._visitables.get("custom").remove(this.custom);
    }
    return (A) this;
  }
  
  public boolean hasCustom() {
    return this.custom != null;
  }
  
  public CustomNested<A> withNewCustom() {
    return new CustomNested(null);
  }
  
  public CustomNested<A> withNewCustomLike(FeatureGatesEnabled item) {
    return new CustomNested(item);
  }
  
  public CustomNested<A> editCustom() {
    return withNewCustomLike(java.util.Optional.ofNullable(buildCustom()).orElse(null));
  }
  
  public CustomNested<A> editOrNewCustom() {
    return withNewCustomLike(java.util.Optional.ofNullable(buildCustom()).orElse(new FeatureGatesEnabledBuilder().build()));
  }
  
  public CustomNested<A> editOrNewCustomLike(FeatureGatesEnabled item) {
    return withNewCustomLike(java.util.Optional.ofNullable(buildCustom()).orElse(item));
  }
  
  public String getFeatureSet() {
    return this.featureSet;
  }
  
  public A withFeatureSet(String featureSet) {
    this.featureSet = featureSet;
    return (A) this;
  }
  
  public boolean hasFeatureSet() {
    return this.featureSet != null;
  }
  
  public A addToAdditionalProperties(String key,Object value) {
    if(this.additionalProperties == null && key != null && value != null) { this.additionalProperties = new LinkedHashMap(); }
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (A)this;
  }
  
  public A addToAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null && map != null) { this.additionalProperties = new LinkedHashMap(); }
    if(map != null) { this.additionalProperties.putAll(map);} return (A)this;
  }
  
  public A removeFromAdditionalProperties(String key) {
    if(this.additionalProperties == null) { return (A) this; }
    if(key != null && this.additionalProperties != null) {this.additionalProperties.remove(key);} return (A)this;
  }
  
  public A removeFromAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.additionalProperties != null){this.additionalProperties.remove(key);}}} return (A)this;
  }
  
  public Map<String,Object> getAdditionalProperties() {
    return this.additionalProperties;
  }
  
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties) {
    if (additionalProperties == null) {
      this.additionalProperties = null;
    } else {
      this.additionalProperties = new LinkedHashMap(additionalProperties);
    }
    return (A) this;
  }
  
  public boolean hasAdditionalProperties() {
    return this.additionalProperties != null;
  }
  
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    FeatureGateSelectionFluent that = (FeatureGateSelectionFluent) o;
    if (!java.util.Objects.equals(custom, that.custom)) return false;
    if (!java.util.Objects.equals(featureSet, that.featureSet)) return false;
    if (!java.util.Objects.equals(additionalProperties, that.additionalProperties)) return false;
    return true;
  }
  
  public int hashCode() {
    return java.util.Objects.hash(custom,  featureSet,  additionalProperties,  super.hashCode());
  }
  
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (custom != null) { sb.append("custom:"); sb.append(custom + ","); }
    if (featureSet != null) { sb.append("featureSet:"); sb.append(featureSet + ","); }
    if (additionalProperties != null && !additionalProperties.isEmpty()) { sb.append("additionalProperties:"); sb.append(additionalProperties); }
    sb.append("}");
    return sb.toString();
  }
  public class CustomNested<N> extends FeatureGatesEnabledFluent<CustomNested<N>> implements Nested<N>{
    CustomNested(FeatureGatesEnabled item) {
      this.builder = new FeatureGatesEnabledBuilder(this, item);
    }
    FeatureGatesEnabledBuilder builder;
    
    public N and() {
      return (N) FeatureGateSelectionFluent.this.withCustom(builder.build());
    }
    
    public N endCustom() {
      return and();
    }
    
  
  }

}
